@@ -2,13 +2,15 @@ package DateTime::Locale::Base;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.02';
+our $VERSION = '1.09';
 
 use Carp qw( carp );
 use DateTime::Locale;
-use List::MoreUtils ();
-use Params::Validate qw( validate_pos );
+use List::Util 1.45 ();
+use Params::ValidationCompiler 0.13 qw( validation_for );
+use Specio::Declare;
 
 BEGIN {
     foreach my $field (
@@ -93,8 +95,7 @@ sub available_formats {
     # The various parens seem to be necessary to force uniq() to see
     # the caller's list context. Go figure.
     my @uniq
-        = List::MoreUtils::uniq(
-        map { keys %{ $_->_available_formats() || {} } }
+        = List::Util::uniq( map { keys %{ $_->_available_formats() || {} } }
             _self_and_super_path( ref $self ) );
 
     # Doing the sort in the same expression doesn't work under 5.6.x.
@@ -142,10 +143,16 @@ sub _available_formats { }
 
 sub default_date_format_length { $_[0]->{default_date_format_length} }
 
+my $length = enum( values => [qw( full long medium short )] );
+my $validator = validation_for(
+    name             => '_check_length_parameter',
+    name_is_optional => 1,
+    params           => [ { type => $length } ],
+);
+
 sub set_default_date_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)$/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_date_format_length} = lc $l;
 }
@@ -154,8 +161,7 @@ sub default_time_format_length { $_[0]->{default_time_format_length} }
 
 sub set_default_time_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_time_format_length} = lc $l;
 }
@@ -460,8 +466,8 @@ sub STORABLE_freeze {
 }
 
 sub STORABLE_thaw {
-    my $self       = shift;
-    my $cloning    = shift;
+    my $self = shift;
+    shift;
     my $serialized = shift;
 
     my $obj = DateTime::Locale->load($serialized);
@@ -479,13 +485,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Locale::Base - Base class for individual locale objects
 
 =head1 VERSION
 
-version 1.02
+version 1.09
 
 =head1 SYNOPSIS
 
@@ -797,13 +805,21 @@ one exists.
 
 See L<DateTime::Locale>.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Locale>
+(or L<bug-datetime-locale@rt.cpan.org|mailto:bug-datetime-locale@rt.cpan.org>).
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2016 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
